@@ -4,9 +4,12 @@
 # ==================
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __project__ = 'pylama_pylint'
 __author__ = "horneds <horneds@gmail.com>"
 __license__ = "BSD"
 
-from .main import Linter
+try:
+    from .main import Linter
+except ImportError:
+    Linter = None
